==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/ko.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "저장소를 사용할 수 없음",
    "Storage invalid" : "저장소가 잘못됨",
    "Unknown error" : "알 수 없는 오류",
    "Could not move %s - File with this name already exists" : "항목 %s을(를) 이동시킬 수 없음 - 같은 이름의 파일이 이미 존재함",
    "Could not move %s" : "항목 %s을(를) 이동시킬 수 없음",
    "Permission denied" : "권한 거부됨",
    "The target folder has been moved or deleted." : "대상 폴더가 이동되거나 삭제되었습니다.",
    "The name %s is already used in the folder %s. Please choose a different name." : "이름 %s이(가) 폴더 %s에서 이미 사용 중입니다. 다른 이름을 사용하십시오.",
    "Error when creating the file" : "파일 생성 중 오류 발생",
    "Error when creating the folder" : "폴더 생성 중 오류 발생",
    "Unable to set upload directory." : "업로드 디렉터리를 설정할 수 없습니다.",
    "Invalid Token" : "잘못된 토큰",
    "No file was uploaded. Unknown error" : "파일이 업로드 되지 않았습니다. 알 수 없는 오류입니다",
    "There is no error, the file uploaded with success" : "파일 업로드에 성공하였습니다.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "업로드한 파일이 php.ini의 upload_max_filesize보다 큽니다:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "업로드한 파일 크기가 HTML 폼의 MAX_FILE_SIZE보다 큼",
    "The uploaded file was only partially uploaded" : "파일의 일부분만 업로드됨",
    "No file was uploaded" : "파일이 업로드되지 않았음",
    "Missing a temporary folder" : "임시 폴더가 없음",
    "Failed to write to disk" : "디스크에 쓰지 못했습니다",
    "Not enough storage available" : "저장소가 용량이 충분하지 않습니다.",
    "Upload failed. Could not find uploaded file" : "업로드에 실패했습니다. 업로드할 파일을 찾을 수 없습니다",
    "Upload failed. Could not get file info." : "업로드에 실패했습니다. 파일 정보를 가져올 수 없습니다.",
    "Invalid directory." : "올바르지 않은 디렉터리입니다.",
    "Files" : "파일",
    "All files" : "모든 파일",
    "Favorites" : "즐겨찾기",
    "Home" : "가정",
    "Close" : "닫기",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename}을(를) 업로드할 수 없습니다. 폴더이거나 0 바이트 파일입니다.",
    "Total file size {size1} exceeds upload limit {size2}" : "총 파일 크기 {size1}이(가) 업로드 제한 {size2}을(를) 초과함",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "빈 공간이 부족합니다. 업로드할 파일 크기는 {size1}이지만 현재 {size2}만큼 비었습니다",
    "Upload cancelled." : "업로드가 취소되었습니다.",
    "Could not get result from server." : "서버에서 결과를 가져올 수 없습니다.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "파일 업로드가 진행 중입니다. 이 페이지를 벗어나면 업로드가 취소됩니다.",
    "Actions" : "작업",
    "Download" : "다운로드",
    "Rename" : "이름 바꾸기",
    "Delete" : "삭제",
    "Details" : "자세한 정보",
    "Select" : "선택",
    "Pending" : "대기 중",
    "Unable to determine date" : "날짜를 결정할 수 없음",
    "This operation is forbidden" : "이 작업이 금지됨",
    "This directory is unavailable, please check the logs or contact the administrator" : "디렉터리를 사용할 수 없습니다. 로그를 확인하거나 관리자에게 연락하십시오",
    "Error moving file." : "파일 이동 오류.",
    "Error moving file" : "파일 이동 오류",
    "Error" : "오류",
    "{new_name} already exists" : "{new_name}이(가) 이미 존재함",
    "Could not rename file" : "이름을 변경할 수 없음",
    "Could not create file" : "파일을 만들 수 없음",
    "Could not create folder" : "폴더를 만들 수 없음",
    "Error deleting file." : "파일 삭제 오류.",
    "No entries in this folder match '{filter}'" : "이 폴더에 '{filter}'와(과) 일치하는 항목 없음",
    "Name" : "이름",
    "Size" : "크기",
    "Modified" : "수정됨",
    "_%n folder_::_%n folders_" : ["폴더 %n개"],
    "_%n file_::_%n files_" : ["파일 %n개"],
    "{dirs} and {files}" : "{dirs} 그리고 {files}",
    "You don’t have permission to upload or create files here" : "여기에 파일을 업로드하거나 만들 권한이 없습니다",
    "_Uploading %n file_::_Uploading %n files_" : ["파일 %n개 업로드 중"],
    "New" : "새로 만들기",
    "\"{name}\" is an invalid file name." : "\"{name}\"은(는) 잘못된 파일 이름입니다.",
    "File name cannot be empty." : "파일 이름이 비어 있을 수 없습니다.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner}의 저장소가 가득 찼습니다. 파일을 더 이상 업데이트하거나 동기화할 수 없습니다!",
    "Your storage is full, files can not be updated or synced anymore!" : "저장 공간이 가득 찼습니다. 파일을 업데이트하거나 동기화할 수 없습니다!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner}의 저장 공간이 거의 가득 찼습니다({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "저장 공간이 거의 가득 찼습니다({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["'{filter}'와(과) 일치"],
    "Path" : "경로",
    "_%n byte_::_%n bytes_" : ["%n바이트"],
    "Favorited" : "책갈피에 추가됨",
    "Favorite" : "즐겨찾기",
    "{newname} already exists" : "{newname} 항목이 이미 존재함",
    "Upload" : "업로드",
    "Text file" : "텍스트 파일",
    "New text file.txt" : "새 텍스트 파일.txt",
    "Folder" : "폴더",
    "New folder" : "새 폴더",
    "An error occurred while trying to update the tags" : "태그를 업데이트하는 중 오류 발생",
    "A new file or folder has been <strong>created</strong>" : "새 파일이나 폴더가 <strong>생성됨</strong>",
    "A file or folder has been <strong>changed</strong>" : "파일이나 폴더가 <strong>변경됨</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>즐겨찾는 파일</strong>의 생성 및 변경 사항에 대한 알림을 줄일 수 있습니다<em>(스트림에서만)</em>",
    "A file or folder has been <strong>deleted</strong>" : "파일이나 폴더가 <strong>삭제됨</strong>",
    "A file or folder has been <strong>restored</strong>" : "파일이나 폴더가 <strong>복원됨</strong>",
    "You created %1$s" : "내가 %1$s을(를) 생성함",
    "%2$s created %1$s" : "%2$s 님이 %1$s을(를) 생성함",
    "%1$s was created in a public folder" : "공유 폴더에 %1$s 생성됨",
    "You changed %1$s" : "내가 %1$s을(를) 변경함",
    "%2$s changed %1$s" : "%2$s 님이 %1$s을(를) 변경함",
    "You deleted %1$s" : "내가 %1$s을(를) 삭제함",
    "%2$s deleted %1$s" : "%2$s 님이 %1$s을(를) 삭제함",
    "You restored %1$s" : "내가 %1$s을(를) 복원함",
    "%2$s restored %1$s" : "%2$s 님이 %1$s을(를) 복원함",
    "Changed by %2$s" : "%2$s 님이 변경함",
    "Deleted by %2$s" : "%2$s 님이 삭제함",
    "Restored by %2$s" : "%2$s 님이 복원함",
    "%s could not be renamed as it has been deleted" : "%s이(가) 삭제되었기 때문에 이름을 변경할 수 없습니다",
    "%s could not be renamed" : "%s의 이름을 변경할 수 없습니다",
    "Upload (max. %s)" : "업로드(최대 %s)",
    "File handling" : "파일 처리",
    "Maximum upload size" : "최대 업로드 크기",
    "max. possible: " : "최대 가능:",
    "With PHP-FPM this value may take up to 5 minutes to take effect after saving." : "PHP-FPM을 사용하고 있으면 설정 변화가 적용될 때까지 5분 정도 걸릴 수 있습니다.",
    "Save" : "저장",
    "Can not be edited from here due to insufficient permissions." : "권한이 부족하므로 여기에서 편집할 수 없습니다.",
    "Settings" : "설정",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "WebDAV로 파일에 접근하려면 <a href=\"%s\" target=\"_blank\">이 주소를 사용하십시오</a>",
    "Cancel upload" : "업로드 취소",
    "No files in here" : "여기에 파일 없음",
    "Upload some content or sync with your devices!" : "파일을 업로드하거나 장치와 동기화하십시오!",
    "No entries found in this folder" : "이 폴더에 항목 없음",
    "Select all" : "모두 선택",
    "Upload too large" : "업로드한 파일이 너무 큼",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "이 파일이 서버에서 허용하는 최대 업로드 가능 용량보다 큽니다.",
    "Files are being scanned, please wait." : "파일을 검색하고 있습니다. 기다려 주십시오.",
    "Currently scanning" : "현재 검사 중",
    "No favorites" : "책갈피 없음",
    "Files and folders you mark as favorite will show up here" : "책갈피에 추가한 파일과 폴더가 여기에 나타납니다"
},
"nplurals=1; plural=0;");

==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/ko.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "저장소를 사용할 수 없음",
    "Storage invalid" : "저장소가 잘못됨",
    "Unknown error" : "알 수 없는 오류",
    "Unable to set upload directory." : "업로드 디렉터리를 설정할 수 없습니다.",
    "Invalid Token" : "잘못된 토큰",
    "No file was uploaded. Unknown error" : "파일이 업로드 되지 않았습니다. 알 수 없는 오류입니다",
    "There is no error, the file uploaded with success" : "파일 업로드에 성공했습니다.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "업로드한 파일이 php.ini의 upload_max_filesize보다 큽니다:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "업로드한 파일 크기가 HTML 폼의 MAX_FILE_SIZE보다 큼",
    "The uploaded file was only partially uploaded" : "파일의 일부분만 업로드됨",
    "No file was uploaded" : "파일이 업로드되지 않았음",
    "Missing a temporary folder" : "임시 폴더가 없음",
    "Failed to write to disk" : "디스크에 쓰지 못했습니다",
    "Not enough storage available" : "저장소가 용량이 충분하지 않습니다.",
    "The target folder has been moved or deleted." : "대상 폴더가 이동되거나 삭제되었습니다.",
    "Upload failed. Could not find uploaded file" : "업로드에 실패했습니다. 업로드할 파일을 찾을 수 없습니다",
    "Upload failed. Could not get file info." : "업로드에 실패했습니다. 파일 정보를 가져올 수 없습니다.",
    "Invalid directory." : "올바르지 않은 디렉터리입니다.",
    "Files" : "파일",
    "All files" : "모든 파일",
    "Favorites" : "즐겨찾기",
    "Home" : "가정",
    "Close" : "닫기",
    "Upload cancelled." : "업로드가 취소되었습니다.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename}을(를) 업로드할 수 없습니다. 폴더이거나 0 바이트 파일입니다.",
    "Total file size {size1} exceeds upload limit {size2}" : "총 파일 크기 {size1}이(가) 업로드 제한 {size2}을(를) 초과함",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "빈 공간이 부족합니다. 업로드할 파일 크기는 {size1}이지만 현재 {size2}만큼 비었습니다",
    "Could not get result from server." : "서버에서 결과를 가져올 수 없습니다.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "파일 업로드가 진행 중입니다. 이 페이지를 벗어나면 업로드가 취소됩니다.",
    "Actions" : "작업",
    "Download" : "다운로드",
    "Rename" : "이름 바꾸기",
    "Delete" : "삭제",
    "Disconnect storage" : "저장소 연결 해제",
    "Unshare" : "공유 해제",
    "Details" : "자세한 정보",
    "Select" : "선택",
    "Pending" : "대기 중",
    "Unable to determine date" : "날짜를 결정할 수 없음",
    "This operation is forbidden" : "이 작업이 금지됨",
    "This directory is unavailable, please check the logs or contact the administrator" : "디렉터리를 사용할 수 없습니다. 로그를 확인하거나 관리자에게 연락하십시오",
    "No entries in this folder match '{filter}'" : "이 폴더에 '{filter}'와(과) 일치하는 항목 없음",
    "Name" : "이름",
    "Size" : "크기",
    "Modified" : "수정됨",
    "_%n folder_::_%n folders_" : ["폴더 %n개"],
    "_%n file_::_%n files_" : ["파일 %n개"],
    "{dirs} and {files}" : "{dirs} 그리고 {files}",
    "You don’t have permission to upload or create files here" : "여기에 파일을 업로드하거나 만들 권한이 없습니다",
    "_Uploading %n file_::_Uploading %n files_" : ["파일 %n개 업로드 중"],
    "New" : "새로 만들기",
    "\"{name}\" is an invalid file name." : "\"{name}\"은(는) 잘못된 파일 이름입니다.",
    "File name cannot be empty." : "파일 이름이 비어 있을 수 없습니다.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner}의 저장소가 가득 찼습니다. 파일을 더 이상 업데이트하거나 동기화할 수 없습니다!",
    "Your storage is full, files can not be updated or synced anymore!" : "저장 공간이 가득 찼습니다. 파일을 업데이트하거나 동기화할 수 없습니다!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner}의 저장 공간이 거의 가득 찼습니다({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "저장 공간이 거의 가득 찼습니다({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["'{filter}'와(과) 일치"],
    "Path" : "경로",
    "_%n byte_::_%n bytes_" : ["%n바이트"],
    "Favorited" : "책갈피에 추가됨",
    "Favorite" : "즐겨찾기",
    "Folder" : "폴더",
    "New folder" : "새 폴더",
    "{newname} already exists" : "{newname} 항목이 이미 존재함",
    "Upload" : "업로드",
    "An error occurred while trying to update the tags" : "태그를 업데이트하는 중 오류 발생",
    "A new file or folder has been <strong>created</strong>" : "새 파일이나 폴더가 <strong>생성됨</strong>",
    "A file or folder has been <strong>changed</strong>" : "파일이나 폴더가 <strong>변경됨</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>즐겨찾는 파일</strong>의 생성 및 변경 사항에 대한 알림을 줄일 수 있습니다<em>(스트림에서만)</em>",
    "A file or folder has been <strong>deleted</strong>" : "파일이나 폴더가 <strong>삭제됨</strong>",
    "A file or folder has been <strong>restored</strong>" : "파일이나 폴더가 <strong>복원됨</strong>",
    "You created %1$s" : "내가 %1$s을(를) 생성함",
    "%2$s created %1$s" : "%2$s 님이 %1$s을(를) 생성함",
    "%1$s was created in a public folder" : "공유 폴더에 %1$s 생성됨",
    "You changed %1$s" : "내가 %1$s을(를) 변경함",
    "%2$s changed %1$s" : "%2$s 님이 %1$s을(를) 변경함",
    "You deleted %1$s" : "내가 %1$s을(를) 삭제함",
    "%2$s deleted %1$s" : "%2$s 님이 %1$s을(를) 삭제함",
    "You restored %1$s" : "내가 %1$s을(를) 복원함",
    "%2$s restored %1$s" : "%2$s 님이 %1$s을(를) 복원함",
    "Changed by %2$s" : "%2$s 님이 변경함",
    "Deleted by %2$s" : "%2$s 님이 삭제함",
    "Restored by %2$s" : "%2$s 님이 복원함",
    "Upload (max. %s)" : "업로드(최대 %s)",
    "File handling" : "파일 처리",
    "Maximum upload size" : "최대 업로드 크기",
    "max. possible: " : "최대 가능:",
    "Save" : "저장",
    "Settings" : "설정",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "WebDAV로 파일에 접근하려면 <a href=\"%s\" target=\"_blank\">이 주소를 사용하십시오</a>",
    "Cancel upload" : "업로드 취소",
    "No files in here" : "여기에 파일 없음",
    "Upload some content or sync with your devices!" : "파일을 업로드하거나 장치와 동기화하십시오!",
    "No entries found in this folder" : "이 폴더에 항목 없음",
    "Select all" : "모두 선택",
    "Upload too large" : "업로드한 파일이 너무 큼",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "이 파일이 서버에서 허용하는 최대 업로드 가능 용량보다 큽니다.",
    "No favorites" : "책갈피 없음",
    "Files and folders you mark as favorite will show up here" : "책갈피에 추가한 파일과 폴더가 여기에 나타납니다",
    "Text file" : "텍스트 파일",
    "New text file.txt" : "새 텍스트 파일.txt",
    "Changed by %2$s" : "%2$s 님이 변경함",
    "Deleted by %2$s" : "%2$s 님이 삭제함",
    "Restored by %2$s" : "%2$s 님이 복원함",
    "You changed %1$s" : "내가 %1$s을(를) 변경함",
    "You created %1$s" : "내가 %1$s을(를) 생성함",
    "You deleted %1$s" : "내가 %1$s을(를) 삭제함",
    "You restored %1$s" : "내가 %1$s을(를) 복원함"
},
"nplurals=1; plural=0;");
